@@ -1,8 +1,8 @@
 package SVG::DOM;
 use strict;
-use warnings;
+
 use vars qw($VERSION);
-$VERSION = "2.43";
+$VERSION = "1.03";
 
 # this module extends SVG::Element
 package SVG::Element;
@@ -570,6 +570,9 @@ SVG::DOM provides a selection of methods for accessing and manipulating SVG
 elements through DOM-like methods such as getElements, getChildren, getNextSibling
 and so on. 
 
+Currently only methods that provide read operations are supported. Methods to
+manipulate SVG elements will be added in a future release.
+
 =head1 SYNOPSIS
 
     my $svg=new SVG(id=>"svg_dom_synopsis", width=>"100", height=>"100");
@@ -751,6 +754,8 @@ Martin Owens, doctormo@postmaster.co.uk
 
 perl(1), L<SVG>, L<SVG::XML>, L<SVG::Element>, L<SVG::Parser>, L<SVG::Manual>
 
+L<http://www.roitsystems.com/> ROASP.com: Serverside SVG server
+L<http://www.vectoreal.com/> Vectoreal: Commercal SVG Application solutions
 L<http://www.roitsystems.com/> ROIT Systems: Commercial SVG perl solutions
 L<http://www.w3c.org/Graphics/SVG/> SVG at the W3C
 
