@@ -6,13 +6,12 @@ SVG::XML - Handle the XML generation bits for SVG.pm
 
 =head1 AUTHOR
 
-Ronan Oger, ronan@roasp.com
+Ronan Oger, cpan@roitsystems.com
 
 =head1 SEE ALSO
 
 perl(1),L<SVG>,L<SVG::XML>,L<SVG::Element>,L<SVG::Parser>, L<SVG::Manual>
-L<http://www.roasp.com/> ROASP.com: Serverside SVG server
-L<http://www.vectoreal.com/> Vectoreal: Commercal SVG Application solutions
+L<http://www.roitsystems.com/> ROASP.com: Serverside SVG server
 L<http://www.roitsystems.com/> ROIT Systems: Commercial SVG perl solutions
 L<http://www.w3c.org/Graphics/SVG/> SVG at the W3C
 
