@@ -29,4 +29,7 @@ print("Failed on getChildren 2: 8") and exit(0)
 print("Failed on getChildren 3: 8") and exit(0)
   if $children[2] != $child3;
 
+print("Failed on getRootElement: 9") and exit(0)
+  unless $parent->getRootElement()->getElementName() eq 'svg';
+
 exit 1;
